LVOC Model of Stroop XOR Task (Bustamante et al. 2017)
======================================================
`"Learning to (mis) allocate control: maltransfer can lead to self-control failure"
<https://scholar.google.com/scholar?hl=en&as_sdt=0%2C31&q=laura+bustamante+cohen+musslick&btnG=>`_.

Implements a model of the Stroop XOR task using a version of the Learned Value of Control (LVOC) model described in
`Leider et al. (2018) <https://journals.plos.org/ploscompbiol/article?id=10.1371/journal.pcbi.1006043&rev=2>`_.

Script: :download:`Bustamante_Stroop_XOR_LVOC_Model.py <../../Scripts/Models/Bustamante_Stroop_XOR_LVOC_Model.py>`


